@@ -186,10 +186,7 @@ class HDFEOSBaseFileReader(BaseFileHandler):
             return self._start_time_from_filename()
 
     def _start_time_from_filename(self):
-        for fn_key in ("start_time", "acquisition_time"):
-            if fn_key in self.filename_info:
-                return self.filename_info[fn_key]
-        raise RuntimeError("Could not determine file start time")
+        return self.filename_info["start_time"]
 
     @property
     def end_time(self):
