@@ -297,7 +297,12 @@ class NativeMSGFileHandler(BaseFileHandler):
         self.mda['hrv_number_of_columns'] = cols_hrv
 
         if self.header['15_MAIN_PRODUCT_HEADER']['QQOV']['Value'] == 'NOK':
-            warnings.warn("The quality flag for this file indicates not OK. Use this data with caution!", UserWarning)
+            warnings.warn(
+                "The quality flag for this file indicates not OK. "
+                "Use this data with caution!",
+                UserWarning,
+                stacklevel=2
+            )
 
     def _read_trailer(self):
 
