@@ -501,75 +501,146 @@ def fake_area():
     return create_area_def("wingertsberg", 4087, area_extent=[-2_000, -2_000, 2_000, 2_000], shape=(2, 2))
 
 
-_nwcsaf_props = {
-     'cma': ('cma_pal', 'cloudmask', 'CMA', "uint8"),
-     'ct': ('ct_pal', 'cloudtype', 'CT', "uint8"),
-     'ctth_alti': ('ctth_alti_pal', 'cloud_top_height', 'CTTH', "float64"),
-     'ctth_pres': ('ctth_pres_pal', 'cloud_top_pressure', 'CTTH', "float64"),
-     'ctth_tempe': ('ctth_tempe_pal', 'cloud_top_temperature', 'CTTH', "float64"),
-     'cmic_phase': ('cmic_phase_pal', 'cloud_top_phase', 'CMIC', "uint8"),
-     'cmic_reff': ('cmic_reff_pal', 'cloud_drop_effective_radius', 'CMIC', "float64"),
-     'cmic_cot': ('cmic_cot_pal', 'cloud_optical_thickness', 'CMIC', "float64"),
-     'cmic_lwp': ('cmic_lwp_pal', 'cloud_liquid_water_path', 'CMIC', "float64"),
-     'cmic_iwp': ('cmic_iwp_pal', 'cloud_ice_water_path', 'CMIC', "float64"),
-     'pc': ('pc_pal', 'precipitation_probability', 'PC', "uint8"),
-     'crr': ('crr_pal', 'convective_rain_rate', 'CRR', "uint8"),
-     'crr_accum': ('crr_pal', 'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
-     'ishai_tpw': ('ishai_tpw_pal', 'total_precipitable_water', 'iSHAI', "float64"),
-     'ishai_shw': ('ishai_shw_pal', 'showalter_index', 'iSHAI', "float64"),
-     'ishai_li': ('ishai_li_pal', 'lifted_index', 'iSHAI', "float64"),
-     'ci_prob30': ('ci_pal', 'convection_initiation_prob30', 'CI', "float64"),
-     'ci_prob60': ('ci_pal', 'convection_initiation_prob60', 'CI', "float64"),
-     'ci_prob90': ('ci_pal', 'convection_initiation_prob90', 'CI', "float64"),
-     'asii_turb_trop_prob': ('asii_turb_prob_pal', 'asii_prob', 'ASII-NG', "float64"),
-     'MapCellCatType': ('MapCellCatType_pal', 'rdt_cell_type', 'RDT-CW', "uint8")}
+_nwcsaf_geo_props = {
+     'cma_geo': ("geo", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
+     'cma_pps': ("pps", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
+     'cma_extended_pps': ("pps", "cma_extended", None, 'cma_extended_pal', None,
+                          'cloudmask_extended', 'CMA', "uint8"),
+     'cmaprob_pps': ("pps", "cmaprob", None, 'cmaprob_pal', None, 'cloudmask_probability',
+                     'CMAPROB', "uint8"),
+     'ct_geo': ("geo", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
+     'ct_pps': ("pps", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
+     'ctth_alti_geo': ("geo", "ctth_alti", None, 'ctth_alti_pal', None, 'cloud_top_height',
+                       'CTTH', "float64"),
+     'ctth_alti_pps': ("pps", "ctth_alti", None, 'ctth_alti_pal', "ctth_status_flag",
+                       'cloud_top_height', 'CTTH', "float64"),
+     'ctth_pres_geo': ("geo", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
+                       'CTTH', "float64"),
+     'ctth_pres_pps': ("pps", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
+                       'CTTH', "float64"),
+     'ctth_tempe_geo': ("geo", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
+                        'CTTH', "float64"),
+     'ctth_tempe_pps': ("pps", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
+                        'CTTH', "float64"),
+     'cmic_phase_geo': ("geo", "cmic_phase", None, 'cmic_phase_pal', None, 'cloud_top_phase',
+                        'CMIC', "uint8"),
+     'cmic_phase_pps': ("pps", "cmic_phase", None, 'cmic_phase_pal', None, 'cloud_top_phase',
+                        'CMIC', "uint8"),
+     'cmic_reff_geo': ("geo", "cmic_reff", None, 'cmic_reff_pal', None, 'cloud_drop_effective_radius',
+                       'CMIC', "float64"),
+     'cmic_reff_pps': ("pps", "cmic_reff", "cmic_cre", 'cmic_cre_pal', None, 'cloud_drop_effective_radius',
+                       'CMIC', "float64"),
+     'cmic_cot_geo': ("geo", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
+                      'CMIC', "float64"),
+     'cmic_cot_pps': ("pps", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
+                      'CMIC', "float64"),
+     'cmic_cwp_pps': ("pps", "cmic_cwp", None, 'cmic_cwp_pal', None, 'cloud_water_path',
+                      'CMIC', "float64"),
+     'cmic_lwp_geo': ("geo", "cmic_lwp", None, 'cmic_lwp_pal', None, 'cloud_liquid_water_path',
+                      'CMIC', "float64"),
+     'cmic_lwp_pps': ("pps", "cmic_lwp", None, 'cmic_lwp_pal', None, 'liquid_water_path',
+                      'CMIC', "float64"),
+     'cmic_iwp_geo': ("geo", "cmic_iwp", None, 'cmic_iwp_pal', None, 'cloud_ice_water_path',
+                      'CMIC', "float64"),
+     'cmic_iwp_pps': ("pps", "cmic_iwp", None, 'cmic_iwp_pal', None, 'ice_water_path',
+                      'CMIC', "float64"),
+     'pc': ("geo", "pc", None, 'pc_pal', None, 'precipitation_probability', 'PC', "uint8"),
+     'crr': ("geo", "crr", None, 'crr_pal', None, 'convective_rain_rate', 'CRR', "uint8"),
+     'crr_accum': ("geo", "crr_accum", None, 'crr_pal', None,
+                   'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
+     'ishai_tpw': ("geo", "ishai_tpw", None, 'ishai_tpw_pal', None, 'total_precipitable_water',
+                   'iSHAI', "float64"),
+     'ishai_shw': ("geo", "ishai_shw", None, 'ishai_shw_pal', None, 'showalter_index',
+                   'iSHAI', "float64"),
+     'ishai_li': ("geo", "ishai_li", None, 'ishai_li_pal', None, 'lifted_index',
+                  'iSHAI', "float64"),
+     'ci_prob30': ("geo", "ci_prob30", None, 'ci_pal', None, 'convection_initiation_prob30',
+                   'CI', "float64"),
+     'ci_prob60': ("geo", "ci_prob60", None, 'ci_pal', None, 'convection_initiation_prob60',
+                   'CI', "float64"),
+     'ci_prob90': ("geo", "ci_prob90", None, 'ci_pal', None, 'convection_initiation_prob90',
+                   'CI', "float64"),
+     'asii_turb_trop_prob': ("geo", "asii_turb_trop_prob", None, 'asii_turb_prob_pal', None,
+                             'asii_prob', 'ASII-NG', "float64"),
+     'MapCellCatType': ("geo", "MapCellCatType", None, 'MapCellCatType_pal', None,
+                        'rdt_cell_type', 'RDT-CW', "uint8"),
+     }
 
 
 @pytest.mark.parametrize(
         "data",
-        ['cma', 'ct', 'ctth_alti', 'ctth_pres', 'ctth_tempe', 'cmic_phase',
-            'cmic_reff', 'cmic_cot', 'cmic_lwp', 'cmic_iwp', 'pc', 'crr',
-            'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li', 'ci_prob30',
-            'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob', 'MapCellCatType']
+        ['cma_geo', 'cma_pps', 'cma_extended_pps', 'cmaprob_pps', 'ct_geo',
+            'ct_pps', 'ctth_alti_geo', 'ctth_alti_pps', 'ctth_pres_geo',
+            'ctth_pres_pps', 'ctth_tempe_geo', 'ctth_tempe_pps',
+            'cmic_phase_geo', 'cmic_phase_pps', 'cmic_reff_geo',
+            'cmic_reff_pps', 'cmic_cot_geo', 'cmic_cot_pps', 'cmic_cwp_pps',
+            'cmic_lwp_geo', 'cmic_lwp_pps', 'cmic_iwp_geo', 'cmic_iwp_pps',
+            'pc', 'crr', 'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li',
+            'ci_prob30', 'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob',
+            'MapCellCatType']
         )
-def test_producing_mode_p(fake_area, tmp_path, data):
-    """Test producing mode p with  palettizer and ancillary variables."""
+def test_nwcsaf_comps(fake_area, tmp_path, data):
+    """Test loading NWCSAF composites."""
     from satpy.writers import get_enhanced_image
 
     from ... import Scene
-    (palette, comp, label, dtp) = _nwcsaf_props[data]
+    (flavour, dvname, altname, palettename, statusname, comp, filelabel, dtp) = _nwcsaf_geo_props[data]
     rng = (0, 100) if dtp == "uint8" else (-100, 1000)
-    fk = tmp_path / f"S_NWC_{label:s}_MSG2_MSG-N-VISIR_20220124T094500Z.nc"
+    if flavour == "geo":
+        fn = f"S_NWC_{filelabel:s}_MSG2_MSG-N-VISIR_20220124T094500Z.nc"
+        reader = "nwcsaf-geo"
+        id_ = {"satellite_identifier": "MSG4"}
+    else:
+        fn = f"S_NWC_{filelabel:s}_noaa20_00000_20230301T1200213Z_20230301T1201458Z.nc"
+        reader = "nwcsaf-pps_nc"
+        id_ = {"platform": "NOAA-20"}
+    fk = tmp_path / fn
     # create a minimally fake netCDF file, otherwise satpy won't load the
     # composite
     ds = xr.Dataset(
             coords={"nx": [0], "ny": [0]},
             attrs={
                 "source": "satpy unit test",
-                "satellite_identifier": "pranksat",
                 "time_coverage_start": "0001-01-01T00:00:00Z",
-                "time_coverage_end": "0001-01-01T01:00:00Z"
-                })
+                "time_coverage_end": "0001-01-01T01:00:00Z",
+                }
+            )
+    ds.attrs.update(id_)
     ds.to_netcdf(fk)
-    sc = Scene(filenames=[os.fspath(fk)], reader=["nwcsaf-geo"])
-    sc[palette] = xr.DataArray(
+    sc = Scene(filenames=[os.fspath(fk)], reader=[reader])
+    sc[palettename] = xr.DataArray(
             da.tile(da.arange(256), [3, 1]).T,
             dims=("pal02_colors", "pal_RGB"))
     fake_alti = da.linspace(rng[0], rng[1], 4, chunks=2, dtype=dtp).reshape(2, 2)
-    sc[data] = xr.DataArray(
+    ancvars = [sc[palettename]]
+    if statusname is not None:
+        sc[statusname] = xr.DataArray(
+                da.zeros(shape=(2, 2), dtype="uint8"),
+                attrs={
+                    "area": fake_area,
+                    "_FillValue": 123},
+                dims=("y", "x"))
+        ancvars.append(sc[statusname])
+    sc[dvname] = xr.DataArray(
             fake_alti,
             dims=("y", "x"),
             attrs={
                 "area": fake_area,
-                "ancillary_variables": [sc[palette]],
+                "ancillary_variables": ancvars,
                 "valid_range": rng})
-    sc.load([comp])
+
+    def _fake_get_varname(info, info_type="file_key"):
+        return altname or dvname
+    with mock.patch("satpy.readers.nwcsaf_nc.NcNWCSAF._get_varname_in_file") as srnN_:
+        srnN_.side_effect = _fake_get_varname
+        sc.load([comp])
     im = get_enhanced_image(sc[comp])
-    assert im.mode == "P"
-    np.testing.assert_array_equal(im.data.coords["bands"], ["P"])
-    if dtp == "float64":
-        np.testing.assert_allclose(
-                im.data.sel(bands="P"),
-                ((fake_alti - rng[0]) * (255/np.ptp(rng))).round())
-    else:
-        np.testing.assert_allclose(im.data.sel(bands="P"), fake_alti)
+    if flavour == "geo":
+        assert im.mode == "P"
+        np.testing.assert_array_equal(im.data.coords["bands"], ["P"])
+        if dtp == "float64":
+            np.testing.assert_allclose(
+                    im.data.sel(bands="P"),
+                    ((fake_alti - rng[0]) * (255/np.ptp(rng))).round())
+        else:
+            np.testing.assert_allclose(im.data.sel(bands="P"), fake_alti)
