@@ -17,15 +17,16 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Module for testing the satpy.readers.nucaps module."""
 
+import datetime
 import os
 import unittest
-import datetime
 from unittest import mock
+
 import numpy as np
+
 from satpy.tests.reader_tests.test_netcdf_utils import FakeNetCDF4FileHandler
 from satpy.tests.utils import convert_file_content_to_data_array
 
-
 DEFAULT_FILE_DTYPE = np.float32
 DEFAULT_FILE_SHAPE = (120,)
 DEFAULT_PRES_FILE_SHAPE = (120, 100,)
@@ -252,6 +253,20 @@ class TestNUCAPSReader(unittest.TestCase):
             if np.issubdtype(v.dtype, np.floating):
                 assert '_FillValue' not in v.attrs
 
+    def test_load_multiple_files_pressure(self):
+        """Test loading Temperature from multiple input files."""
+        from satpy.readers import load_reader
+        r = load_reader(self.reader_configs)
+        loadables = r.select_files_from_pathnames([
+            'NUCAPS-EDR_v1r0_npp_s201603011158009_e201603011158307_c201603011222270.nc',
+            'NUCAPS-EDR_v1r0_npp_s201603011159009_e201603011159307_c201603011222270.nc',
+        ])
+        r.create_filehandlers(loadables)
+        datasets = r.load(r.pressure_dataset_names['Temperature'], pressure_levels=True)
+        self.assertEqual(len(datasets), 100)
+        for v in datasets.values():
+            self.assertEqual(v.ndim, 1)
+
     def test_load_individual_pressure_levels_true(self):
         """Test loading Temperature with individual pressure datasets."""
         from satpy.readers import load_reader
