@@ -372,7 +372,10 @@ def _get_sat_altitude(data_arr, key_prefixes):
         alt = _get_first_available_item(orb_params, alt_keys)
     except KeyError:
         alt = orb_params['projection_altitude']
-        warnings.warn('Actual satellite altitude not available, using projection altitude instead.')
+        warnings.warn(
+            'Actual satellite altitude not available, using projection altitude instead.',
+            stacklevel=3
+        )
     return alt
 
 
@@ -386,7 +389,10 @@ def _get_sat_lonlat(data_arr, key_prefixes):
     except KeyError:
         lon = orb_params['projection_longitude']
         lat = orb_params['projection_latitude']
-        warnings.warn('Actual satellite lon/lat not available, using projection center instead.')
+        warnings.warn(
+            'Actual satellite lon/lat not available, using projection center instead.',
+            stacklevel=3
+        )
     return lon, lat
 
 
